# crypto-ai-agent
crypto-ai-agent is a python package to help users create agents serve for different kinds of tasks in the Web3 and Crypto world. Crypto is fast-evolving with new knowledge everyday, keep learning and keep alerting is usually hard as there are so many opportunities to miss out. So, the best solution is, AI Agent! You can use this library to create your own AI Agents which feeds with different domain knowledge to do the tasks you assign to. This project is fully open source and you can use it as much as you want. 

## What this library do? 
Training the agents is hard, and we do the hard part for you. This project is more like a wrap up toolbox for the immediate use of the power of AI. What you need to do is take the agents and formulate a team, which works best for you. 

## Structure of Agents
Agents are not bots. They are not just lame lines of codes to follow the streamline work, instead, agents are free to use their knowledge to explore the information and take actions. 
### Configuration 

### Actions

## Types of Agents
### Crypto Analyst 

### Cryto Professor

### Cryto Engineer

### Crypto Blacksmith

### Crypto Artist 

## Blueprint
To further support the automated work, we introduct Blueprint, which serves as a higher level of automated work, it is predesigned part of work and you don't need to create it

## What this project can do? 
